You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@openoffice.apache.org by pf...@apache.org on 2014/04/29 21:05:21 UTC

svn commit: r1591058 [4/15] - in /openoffice/trunk/main: ./ accessibility/bridge/org/openoffice/java/accessibility/ accessibility/bridge/source/java/ accessibility/inc/accessibility/extended/ accessibility/inc/accessibility/standard/ accessibility/sour...

Modified: openoffice/trunk/main/cli_ure/source/native/makefile.mk
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/cli_ure/source/native/makefile.mk?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/cli_ure/source/native/makefile.mk (original)
+++ openoffice/trunk/main/cli_ure/source/native/makefile.mk Tue Apr 29 19:05:05 2014
@@ -152,7 +152,7 @@ $(SIGN): $(SHL1TARGETN)
 #do not forget to deliver cli_cppuhelper.config. It is NOT embedded in the policy file.
 .IF "$(CCNUMVER)" >= "001399999999"		
 #.NET 2 and higher	
-# If the x86 switch is ommitted then the system assumes the assembly to be MSIL.
+# If the x86 switch is omitted then the system assumes the assembly to be MSIL.
 # The policy file is still found when an application tries to load an older
 # cli_cppuhelper.dll but the system cannot locate it. It possibly assumes that the
 # assembly is also 'MSIL'  like its policy file.

Modified: openoffice/trunk/main/cli_ure/source/native/native_bootstrap.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/cli_ure/source/native/native_bootstrap.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/cli_ure/source/native/native_bootstrap.cxx (original)
+++ openoffice/trunk/main/cli_ure/source/native/native_bootstrap.cxx Tue Apr 29 19:05:05 2014
@@ -69,7 +69,7 @@ namespace
  * @param subKeyName  name of the subkey to open
  *
  * @return the installation path or NULL, if no installation was found or
- *         if an error occured
+ *         if an error occurred
  */
 WCHAR* getPathFromRegistryKey( HKEY hroot, LPCWSTR subKeyName )
 {

Modified: openoffice/trunk/main/cli_ure/source/uno_bridge/cli_bridge.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/cli_ure/source/uno_bridge/cli_bridge.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/cli_ure/source/uno_bridge/cli_bridge.cxx (original)
+++ openoffice/trunk/main/cli_ure/source/uno_bridge/cli_bridge.cxx Tue Apr 29 19:05:05 2014
@@ -190,8 +190,8 @@ namespace cli_uno
     I doubt that the the case that the ref count raises from 0 to 1
     can occur.  uno_ext_getMapping returns an acquired mapping. Every time
     that function is called then a new mapping is created. Following the
-    rules of ref counted objects, then if the ref count is null noone has
-    a reference to the object anymore. Hence noone can call acquire. If someone
+    rules of ref counted objects, then if the ref count is null no one has
+    a reference to the object anymore. Hence no one can call acquire. If someone
     calls acquire then they must have kept an unacquired pointer which is
     illegal.
  */

Modified: openoffice/trunk/main/cli_ure/source/uno_bridge/cli_data.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/cli_ure/source/uno_bridge/cli_data.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/cli_ure/source/uno_bridge/cli_data.cxx (original)
+++ openoffice/trunk/main/cli_ure/source/uno_bridge/cli_data.cxx Tue Apr 29 19:05:05 2014
@@ -1647,7 +1647,7 @@ void Bridge::map_to_cli(
                 }
                 OSL_ASSERT (nPos != -1);
                 int offset = pCTD->pMemberOffsets[nPos];
-                //Whith the offset within the exception we can get the message string
+                //With the offset within the exception we can get the message string
                 System::String* sMessage = mapUnoString(*(rtl_uString**)
                                                         ((char*) uno_data + offset));
                 //We need to find a constructor for the exception that takes the message string

Modified: openoffice/trunk/main/cli_ure/source/uno_bridge/cli_proxy.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/cli_ure/source/uno_bridge/cli_proxy.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/cli_ure/source/uno_bridge/cli_proxy.cxx (original)
+++ openoffice/trunk/main/cli_ure/source/uno_bridge/cli_proxy.cxx Tue Apr 29 19:05:05 2014
@@ -1102,7 +1102,7 @@ void SAL_CALL cli_proxy_dispatch(
                     {
                         uno_any_construct( (uno_Any *)uno_ret, 0, 0, 0 );
                     }
-                    // no excetpion occured
+                    // no excetpion occurred
                     *uno_exc = 0;                    
                 }
                 else

Modified: openoffice/trunk/main/cli_ure/source/uno_bridge/cli_uno.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/cli_ure/source/uno_bridge/cli_uno.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/cli_ure/source/uno_bridge/cli_uno.cxx (original)
+++ openoffice/trunk/main/cli_ure/source/uno_bridge/cli_uno.cxx Tue Apr 29 19:05:05 2014
@@ -183,7 +183,7 @@ System::Object* Bridge::call_uno(uno_Int
         }
         return 0; // void return
     }
-    else // exception occured
+    else // exception occurred
     {
         // destruct uno in args
         for ( sal_Int32 nPos = 0; nPos < nParams; ++nPos )
@@ -276,7 +276,7 @@ void Bridge::call_cli(
         map_to_uno(
             uno_ret, retInvoke, return_type, false /* no assign */);
     }        
-    // no exception occured
+    // no exception occurred
     *uno_exc = 0;
 }
 

Modified: openoffice/trunk/main/codemaker/source/javamaker/javatype.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/codemaker/source/javamaker/javatype.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/codemaker/source/javamaker/javatype.cxx (original)
+++ openoffice/trunk/main/codemaker/source/javamaker/javatype.cxx Tue Apr 29 19:05:05 2014
@@ -2171,7 +2171,7 @@ void handleInterfaceType(
                 rtl::OString(
                     RTL_CONSTASCII_STRINGPARAM("Bad type information"))); //TODO
         }
-        //TODO: exploit the fact that attribute getter/setter methods preceed
+        //TODO: exploit the fact that attribute getter/setter methods precede
         // real methods
         rtl::OUString attrNameUtf16(reader.getFieldName(i));
         sal_uInt16 getter = SAL_MAX_UINT16;

Modified: openoffice/trunk/main/comphelper/inc/comphelper/IdPropArrayHelper.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/comphelper/inc/comphelper/IdPropArrayHelper.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/comphelper/inc/comphelper/IdPropArrayHelper.hxx (original)
+++ openoffice/trunk/main/comphelper/inc/comphelper/IdPropArrayHelper.hxx Tue Apr 29 19:05:05 2014
@@ -66,7 +66,7 @@ namespace comphelper
 		}
 
 		/** call this in the getInfoHelper method of your derived class. The method returns the array helper of the
-			class, which is created if neccessary.
+			class, which is created if necessary.
 		*/
 		::cppu::IPropertyArrayHelper* getArrayHelper(sal_Int32 nId);
 

Modified: openoffice/trunk/main/comphelper/inc/comphelper/accessiblecontexthelper.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/comphelper/inc/comphelper/accessiblecontexthelper.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/comphelper/inc/comphelper/accessiblecontexthelper.hxx (original)
+++ openoffice/trunk/main/comphelper/inc/comphelper/accessiblecontexthelper.hxx Tue Apr 29 19:05:05 2014
@@ -118,7 +118,7 @@ namespace comphelper
 			the context does. A good approach to implement the lock may be to derive you own context
 			not only from OAccessibleContextHelper, but also from IMutex.</p>
 
-			<p>One more note. This lock is definately not used once the dtor is reached. Means whatever
+			<p>One more note. This lock is definitely not used once the dtor is reached. Means whatever
 			the dtor implementation does, it does <em>not</em> guard the external lock. See this as a contract.
 			<br/>You should ensure the same thing for own derivees which do not supply the lock themself,
 			but get them from yet another derivee.</p>

Modified: openoffice/trunk/main/comphelper/inc/comphelper/accimplaccess.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/comphelper/inc/comphelper/accimplaccess.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/comphelper/inc/comphelper/accimplaccess.hxx (original)
+++ openoffice/trunk/main/comphelper/inc/comphelper/accimplaccess.hxx Tue Apr 29 19:05:05 2014
@@ -105,7 +105,7 @@ namespace comphelper
 		@param _rxComponent
 			is the component which should be examined.
 		@return
-			the pointer to the implementation, if successfull. The only known error condition so far
+			the pointer to the implementation, if successful. The only known error condition so far
 			is an invalid context (which means it is <NULL/>, or the implementation is not derived
 			from <type>OAccessibleImplementationAccess</type>, or retrieving the implementation failed).
 		*/

Modified: openoffice/trunk/main/comphelper/inc/comphelper/componentcontext.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/comphelper/inc/comphelper/componentcontext.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/comphelper/inc/comphelper/componentcontext.hxx (original)
+++ openoffice/trunk/main/comphelper/inc/comphelper/componentcontext.hxx Tue Apr 29 19:05:05 2014
@@ -137,7 +137,7 @@ namespace comphelper
             @throws ::com::sun::star::lang::ServiceNotRegisteredException
                 if the given service is not registered
             @throws Exception
-                if an exception occured during creating the component
+                if an exception occurred during creating the component
             @return
                 the newly created component. Is never <NULL/>.
         */
@@ -148,7 +148,7 @@ namespace comphelper
             @throws ::com::sun::star::lang::ServiceNotRegisteredException
                 if the given service is not registered
             @throws Exception
-                if an exception occured during creating the component
+                if an exception occurred during creating the component
             @return
                 the newly created component. Is never <NULL/>.
         */
@@ -162,7 +162,7 @@ namespace comphelper
             @throws ::com::sun::star::lang::ServiceNotRegisteredException
                 if the given service is not registered
             @throws Exception
-                if an exception occured during creating the component
+                if an exception occurred during creating the component
             @return
                 the newly created component. Is never <NULL/>.
         */
@@ -176,7 +176,7 @@ namespace comphelper
             @throws ::com::sun::star::lang::ServiceNotRegisteredException
                 if the given service is not registered
             @throws Exception
-                if an exception occured during creating the component
+                if an exception occurred during creating the component
             @return
                 the newly created component. Is never <NULL/>.
         */

Modified: openoffice/trunk/main/comphelper/inc/comphelper/configurationhelper.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/comphelper/inc/comphelper/configurationhelper.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/comphelper/inc/comphelper/configurationhelper.hxx (original)
+++ openoffice/trunk/main/comphelper/inc/comphelper/configurationhelper.hxx Tue Apr 29 19:05:05 2014
@@ -41,7 +41,7 @@
 // namespaces
 
 // no panic .. this define will be reseted at the end of this file.
-// BUT doing so it's neccessary to add all includes BEFORE this css-value
+// BUT doing so it's necessary to add all includes BEFORE this css-value
 // will be defined :_)
 #ifdef css
 #error "Who use css? I need it as namespace alias."
@@ -98,7 +98,7 @@ class COMPHELPER_DLLPUBLIC Configuration
      *
      *  @param  eMode
      *          specify the open mode for the returned configuration access.
-     *          It's interpreted as a flag field and can be any usefull combination
+     *          It's interpreted as a flag field and can be any useful combination
      *          of values of EConfigurationModes.
      *
      *  @throw  Any exceptions the underlying configuration can throw.
@@ -191,7 +191,7 @@ class COMPHELPER_DLLPUBLIC Configuration
      *          or which should be created with default values.
      *
      *  @return A reference to the found (or new created) set node.
-     *          Cant be NULL .. in such case an exception occure !
+     *          Can't be NULL .. in such case an exception occurred !
      *
      *  @throw  Any exceptions the underlying configuration can throw.
      *          E.g. css::uno::Exception if the provided configuration
@@ -208,7 +208,7 @@ class COMPHELPER_DLLPUBLIC Configuration
      *  The cached configuration access must be provided here.
      *
      *  @param  xCFG
-     *          the configuration root, where changes should be commited.
+     *          the configuration root, where changes should be committed.
      *
      *  @throw  Any exceptions the underlying configuration can throw.
      *          E.g. css::uno::Exception if the provided configuration
@@ -223,7 +223,7 @@ class COMPHELPER_DLLPUBLIC Configuration
      * Because it opens the specified configuration package, reads the key and
      * closes the configuration again.
      *
-     * So its not very usefull to use this method for reading multiple keys at the same time.
+     * So its not very useful to use this method for reading multiple keys at the same time.
      * (Excepting these keys exists inside different configuration packages ...))
      */
     static css::uno::Any readDirectKey(const css::uno::Reference< css::lang::XMultiServiceFactory > xSMGR   ,
@@ -239,7 +239,7 @@ class COMPHELPER_DLLPUBLIC Configuration
      * Because it opens the specified configuration package, writes the key, flush
      * all changes and closes the configuration again.
      *
-     * So its not very usefull to use this method for writing multiple keys at the same time.
+     * So its not very useful to use this method for writing multiple keys at the same time.
      * (Excepting these keys exists inside different configuration packages ...))
      */
     static void writeDirectKey(const css::uno::Reference< css::lang::XMultiServiceFactory > xSMGR   ,

Modified: openoffice/trunk/main/comphelper/inc/comphelper/containermultiplexer.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/comphelper/inc/comphelper/containermultiplexer.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/comphelper/inc/comphelper/containermultiplexer.hxx (original)
+++ openoffice/trunk/main/comphelper/inc/comphelper/containermultiplexer.hxx Tue Apr 29 19:05:05 2014
@@ -39,7 +39,7 @@ namespace comphelper
 	//= OContainerListener
 	//=====================================================================
 	/** a non-UNO container listener
-		<p>Usefull if you have a non-refcountable class which should act as container listener.<br/>
+		<p>Useful if you have a non-refcountable class which should act as container listener.<br/>
 		In this case, derive this class from OContainerListener, and create an adapter
 		<type>OContainerListenerAdapter</type> which multiplexes the changes.</p>
 	*/

Modified: openoffice/trunk/main/comphelper/inc/comphelper/docpasswordhelper.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/comphelper/inc/comphelper/docpasswordhelper.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/comphelper/inc/comphelper/docpasswordhelper.hxx (original)
+++ openoffice/trunk/main/comphelper/inc/comphelper/docpasswordhelper.hxx Tue Apr 29 19:05:05 2014
@@ -58,7 +58,7 @@ class COMPHELPER_DLLPUBLIC IDocPasswordV
 public:
     virtual             ~IDocPasswordVerifier();
 
-    /** Will be called everytime a password needs to be verified.
+    /** Will be called every time a password needs to be verified.
 
         @param rPassword
             The password to be verified
@@ -74,12 +74,12 @@ public:
             - DocPasswordVerifierResult_WRONG_PASSWORD, if the password is
               wrong. The user may be asked again for a new password.
             - DocPasswordVerifierResult_ABORT, if an unrecoverable error
-              occured while password verification. The password request loop
+              occurred while password verification. The password request loop
               will be aborted.
      */
     virtual DocPasswordVerifierResult verifyPassword( const ::rtl::OUString& rPassword, ::com::sun::star::uno::Sequence< ::com::sun::star::beans::NamedValue >& o_rEncryptionData ) = 0;
 
-    /** Will be called everytime an encryption data needs to be verified.
+    /** Will be called every time an encryption data needs to be verified.
 
         @param rEncryptionData
             The data will be validated
@@ -90,7 +90,7 @@ public:
             - DocPasswordVerifierResult_WRONG_PASSWORD, if the encryption data is
               wrong.
             - DocPasswordVerifierResult_ABORT, if an unrecoverable error
-              occured while data verification. The password request loop
+              occurred while data verification. The password request loop
               will be aborted.
      */
     virtual DocPasswordVerifierResult verifyEncryptionData( const ::com::sun::star::uno::Sequence< ::com::sun::star::beans::NamedValue >& o_rEncryptionData ) = 0;

Modified: openoffice/trunk/main/comphelper/inc/comphelper/embeddedobjectcontainer.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/comphelper/inc/comphelper/embeddedobjectcontainer.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/comphelper/inc/comphelper/embeddedobjectcontainer.hxx (original)
+++ openoffice/trunk/main/comphelper/inc/comphelper/embeddedobjectcontainer.hxx Tue Apr 29 19:05:05 2014
@@ -101,7 +101,7 @@ public:
                         CreateEmbeddedObject( const com::sun::star::uno::Sequence < sal_Int8 >&,
                         const com::sun::star::uno::Sequence < com::sun::star::beans::PropertyValue >&, ::rtl::OUString& );
 
-    // insert an embedded object into the container - objects persistant representation will be added to the storage
+    // insert an embedded object into the container - objects persistent representation will be added to the storage
     sal_Bool            InsertEmbeddedObject( const ::com::sun::star::uno::Reference < ::com::sun::star::embed::XEmbeddedObject >&, ::rtl::OUString& );
 
     // load an embedded object from a MediaDescriptor and insert it into the container
@@ -175,7 +175,7 @@ sal_Bool            RemoveEmbeddedObject
     *
     * \param _xStorage The storeage where to store the objects.
     * \param _bClearModifedFlag If <TRUE/> then the modifed flag will be set to <FALSE/> otherwise nothing happen.
-    * \return <FALSE/> if no error occured, otherwise <TRUE/>.
+    * \return <FALSE/> if no error occurred, otherwise <TRUE/>.
     */
     sal_Bool             SetPersistentEntries(const com::sun::star::uno::Reference< com::sun::star::embed::XStorage >& _xStorage,bool _bClearModifedFlag = true);
 };

Modified: openoffice/trunk/main/comphelper/inc/comphelper/implementationreference.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/comphelper/inc/comphelper/implementationreference.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/comphelper/inc/comphelper/implementationreference.hxx (original)
+++ openoffice/trunk/main/comphelper/inc/comphelper/implementationreference.hxx Tue Apr 29 19:05:05 2014
@@ -56,7 +56,7 @@ namespace comphelper
         As this template is geared towards fast, internal pointer
         access, validity of the UNO reference is _not_ checked for
         every pointer access. The client of this template is
-        responsible to check that, whereever necessary, via the is()
+        responsible to check that, wherever necessary, via the is()
         method.
 
         @tpl CppType

Modified: openoffice/trunk/main/comphelper/inc/comphelper/interaction.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/comphelper/inc/comphelper/interaction.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/comphelper/inc/comphelper/interaction.hxx (original)
+++ openoffice/trunk/main/comphelper/inc/comphelper/interaction.hxx Tue Apr 29 19:05:05 2014
@@ -47,7 +47,7 @@ namespace comphelper
 	*/
 	class OInteractionSelect
 	{
-		sal_Bool	m_bSelected : 1;	/// indicates if the select event occured
+		sal_Bool	m_bSelected : 1;	/// indicates if the select event occurred
 
 	protected:
 		OInteractionSelect() : m_bSelected(sal_False) { }

Modified: openoffice/trunk/main/comphelper/inc/comphelper/locale.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/comphelper/inc/comphelper/locale.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/comphelper/inc/comphelper/locale.hxx (original)
+++ openoffice/trunk/main/comphelper/inc/comphelper/locale.hxx Tue Apr 29 19:05:05 2014
@@ -53,13 +53,13 @@ class COMPHELPER_DLLPUBLIC Locale
 
     public:
     
-        /** @short seperates LANGUAGE and COUNTRY part of an ISO formated Locale. */
+        /** @short separates LANGUAGE and COUNTRY part of an ISO formated Locale. */
         static const sal_Unicode SEPERATOR_LC;
         
-        /** @short seperates COUNTRY and VARIANT part of an ISO formated Locale. */
+        /** @short separates COUNTRY and VARIANT part of an ISO formated Locale. */
         static const sal_Unicode SEPERATOR_CV;
         
-        /** @short seperates COUNTRY and VARIANT part of an ISO formated Locale.
+        /** @short separates COUNTRY and VARIANT part of an ISO formated Locale.
             @descr Its true for some linux derivates only :-( */
         static const sal_Unicode SEPERATOR_CV_LINUX;
         
@@ -105,7 +105,7 @@ class COMPHELPER_DLLPUBLIC Locale
     
     public:
     
-        /** @short will be throw during convertion, if a Locale cant be interpreted. */
+        /** @short will be throw during conversion, if a Locale can't be interpreted. */
         struct MalFormedLocaleException
         {
             public:
@@ -343,8 +343,8 @@ class COMPHELPER_DLLPUBLIC Locale
                         
                         If no "same" nor any "similar" locale could be found,
                         we try "x-default" and "x-notranslate" explicitly.
-                        Sometimes localized variables are optimized and doesnt use
-                        localzation realy. E.g. in case the localized value is a fix
+                        Sometimes localized variables are optimized and doesn't use
+                        localzation really. E.g. in case the localized value is a fix
                         product name.
                         
                         If no locale match till now, we use any other existing
@@ -429,7 +429,7 @@ class COMPHELPER_DLLPUBLIC Locale
                     
             @return [boolean]
                     TRUE if at least one part of such Locale
-                    isnt the same.
+                    isn't the same.
          */
         sal_Bool operator!=(const Locale& aComparable) const;
 };

Modified: openoffice/trunk/main/comphelper/inc/comphelper/mediadescriptor.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/comphelper/inc/comphelper/mediadescriptor.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/comphelper/inc/comphelper/mediadescriptor.hxx (original)
+++ openoffice/trunk/main/comphelper/inc/comphelper/mediadescriptor.hxx Tue Apr 29 19:05:05 2014
@@ -51,7 +51,7 @@ namespace comphelper{
             Further this helper defines often used functions (as e.g. open of the required streams,
             consistent checks etcpp.) and it defines all useable property names.
 
-    @attention  This class isnt threadsafe and must be guarded from outside!
+    @attention  This class isn't threadsafe and must be guarded from outside!
  */
 class COMPHELPER_DLLPUBLIC MediaDescriptor : public SequenceAsHashMap
 {
@@ -144,7 +144,7 @@ class COMPHELPER_DLLPUBLIC MediaDescript
                     to open the stream (as e.g. URL, ReadOnly, PostData etcpp.).
                     It creates a seekable stream and put it into the descriptor.
 
-                    A might existing InteractionHandler will be used automaticly,
+                    A might existing InteractionHandler will be used automatically,
                     to solve problems!
 
                     In case of local file the system file locking is used.
@@ -162,7 +162,7 @@ class COMPHELPER_DLLPUBLIC MediaDescript
                     to open the stream (as e.g. URL, ReadOnly, PostData etcpp.).
                     It creates a seekable stream and put it into the descriptor.
 
-                    A might existing InteractionHandler will be used automaticly,
+                    A might existing InteractionHandler will be used automatically,
                     to solve problems!
 
                     In case of local file the system file locking is used based on
@@ -176,7 +176,7 @@ class COMPHELPER_DLLPUBLIC MediaDescript
         //---------------------------------------
         /** @short  it checks if the descriptor describes a readonly stream.
 
-            @descr  The descriptor itself isnt changed doing so.
+            @descr  The descriptor itself isn't changed doing so.
                     It's only checked if the stream seems to be based
                     of a real readonly file.
 
@@ -318,7 +318,7 @@ class COMPHELPER_DLLPUBLIC MediaDescript
                     to open the stream (as e.g. URL, ReadOnly, PostData etcpp.).
                     It creates a seekable stream and put it into the descriptor.
 
-                    A might existing InteractionHandler will be used automaticly,
+                    A might existing InteractionHandler will be used automatically,
                     to solve problems!
 
             @param  bLockFile

Modified: openoffice/trunk/main/comphelper/inc/comphelper/numberedcollection.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/comphelper/inc/comphelper/numberedcollection.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/comphelper/inc/comphelper/numberedcollection.hxx (original)
+++ openoffice/trunk/main/comphelper/inc/comphelper/numberedcollection.hxx Tue Apr 29 19:05:05 2014
@@ -58,7 +58,7 @@ namespace comphelper{
 /** @short  defines a collection of UNO components, where every component will get it's own unique number. 
 
     @descr  Such number will be unique at runtime only ... but it supports fragmentation.
-            Note: This collection uses weak refrences only to know her components.
+            Note: This collection uses weak references only to know her components.
             So lifetime of thise components must be controlled outside.
             
     @threadsafe
@@ -154,14 +154,14 @@ class COMPHELPER_DLLPUBLIC NumberedColle
         //---------------------------------------
         /** @short  trys to find an unique number not already used within this collection.
     
-            @descr  It reuses the smalles number which isnt used by any component
+            @descr  It reuses the smalles number which isn't used by any component
                     of this collection. (fragmentation!) If collection is full (means there
                     is no free number) the special value INVALID_NUMBER will be returned.
     
-            @note   Those method cant be called within a multithreaded environment ..
+            @note   Those method can't be called within a multithreaded environment ..
                     Because such number wont be "reserved" for the calli of these method
                     it can happen that two calls returns the same number (reasoned by the fact that first calli
-                    doesnt used the returned number already.
+                    doesn't used the returned number already.
     
                     So the outside code has to make sure that retrieving and using of those number
                     will be an atomic operation.

Modified: openoffice/trunk/main/comphelper/inc/comphelper/propagg.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/comphelper/inc/comphelper/propagg.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/comphelper/inc/comphelper/propagg.hxx (original)
+++ openoffice/trunk/main/comphelper/inc/comphelper/propagg.hxx Tue Apr 29 19:05:05 2014
@@ -72,9 +72,9 @@ namespace internal
 class IPropertyInfoService
 {
 public:
-	/**	get the prefered handle for the given property
+	/**	get the preferred handle for the given property
 		@param		_rName		the property name
-		@return					the handle the property should be refered by, or -1 if there are no
+		@return					the handle the property should be referred by, or -1 if there are no
 								preferences for the given property
 	*/
 	virtual	sal_Int32			getPreferedPropertyId(const ::rtl::OUString& _rName) = 0;
@@ -108,11 +108,11 @@ public:
 								aggregate properties get depend from the following two parameters.
 		@param	_pInfoService
 								If not NULL, the object pointed to is used to calc handles which should be used
-								for refering the aggregate's properties from outside.
+								for referring the aggregate's properties from outside.
 								If one of the properties returned from the info service conflict with other handles
 								alread present (e.g. through _rProperties), the property is handled as if -1 was returned.
 								If NULL (or, for a special property, a call to getPreferedPropertyId returns -1),
-								the aggregate property(ies) get a new handle which they can be refered by from outside.
+								the aggregate property(ies) get a new handle which they can be referred by from outside.
 		@param	_nFirstAggregateId
 								if the object is about to create new handles for the aggregate properties, it uses
 								id's ascending from this given id.
@@ -143,8 +143,8 @@ public:
 	virtual sal_Int32 SAL_CALL fillHandles( /*out*/sal_Int32* _pHandles, const ::com::sun::star::uno::Sequence< ::rtl::OUString >& _rPropNames );
 
 	/** returns information about a property of the aggregate.
-		@param	_pPropName			points to a string to recieve the property name. No name is returned if this is NULL.
-		@param	_pOriginalHandle	points to a sal_Int32 to recieve the original property hande. No original handle is returned
+		@param	_pPropName			points to a string to receive the property name. No name is returned if this is NULL.
+		@param	_pOriginalHandle	points to a sal_Int32 to receive the original property hande. No original handle is returned
 									if this is NULL.
 		@param	_nHandle			the handle of the property as got by, for instance, fillHandles
 

Modified: openoffice/trunk/main/comphelper/inc/comphelper/proparrhlp.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/comphelper/inc/comphelper/proparrhlp.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/comphelper/inc/comphelper/proparrhlp.hxx (original)
+++ openoffice/trunk/main/comphelper/inc/comphelper/proparrhlp.hxx Tue Apr 29 19:05:05 2014
@@ -73,7 +73,7 @@ public:
 	}
 
 	/** call this in the getInfoHelper method of your derived class. The method returns the array helper of the
-		class, which is created if neccessary.
+		class, which is created if necessary.
 	*/
 	::cppu::IPropertyArrayHelper*	getArrayHelper();
 

Modified: openoffice/trunk/main/comphelper/inc/comphelper/property.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/comphelper/inc/comphelper/property.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/comphelper/inc/comphelper/property.hxx (original)
+++ openoffice/trunk/main/comphelper/inc/comphelper/property.hxx Tue Apr 29 19:05:05 2014
@@ -138,7 +138,7 @@ COMPHELPER_DLLPUBLIC void copyProperties
 //==================================================================
 
 /** helper for implementing ::cppu::OPropertySetHelper::convertFastPropertyValue
-	@param			_rConvertedValue	the conversion result (if successfull)
+	@param			_rConvertedValue	the conversion result (if successful)
 	@param			_rOldValue			the old value of the property, calculated from _rCurrentValue
 	@param			_rValueToSet		the new value which is about to be set
 	@param			_rCurrentValue		the current value of the property
@@ -162,7 +162,7 @@ sal_Bool tryPropertyValue(staruno::Any& 
 }
 
 /** helper for implementing ::cppu::OPropertySetHelper::convertFastPropertyValue for enum values
-	@param			_rConvertedValue	the conversion result (if successfull)
+	@param			_rConvertedValue	the conversion result (if successful)
 	@param			_rOldValue			the old value of the property, calculated from _rCurrentValue
 	@param			_rValueToSet		the new value which is about to be set
 	@param			_rCurrentValue		the current value of the property
@@ -192,7 +192,7 @@ sal_Bool tryPropertyValueEnum(staruno::A
 }
 
 /** helper for implementing ::cppu::OPropertySetHelper::convertFastPropertyValue for boolean properties
-	@param			_rConvertedValue	the conversion result (if successfull)
+	@param			_rConvertedValue	the conversion result (if successful)
 	@param			_rOldValue			the old value of the property, calculated from _rCurrentValue
 	@param			_rValueToSet		the new value which is about to be set
 	@param			_rCurrentValue		the current value of the property
@@ -215,7 +215,7 @@ inline sal_Bool tryPropertyValue(staruno
 }
 
 /** helper for implementing ::cppu::OPropertySetHelper::convertFastPropertyValue
-	@param			_rConvertedValue	the conversion result (if successfull)
+	@param			_rConvertedValue	the conversion result (if successful)
 	@param			_rOldValue			the old value of the property, calculated from _rCurrentValue
 	@param			_rValueToSet		the new value which is about to be set
 	@param			_rCurrentValue		the current value of the property

Modified: openoffice/trunk/main/comphelper/inc/comphelper/seqstream.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/comphelper/inc/comphelper/seqstream.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/comphelper/inc/comphelper/seqstream.hxx (original)
+++ openoffice/trunk/main/comphelper/inc/comphelper/seqstream.hxx Tue Apr 29 19:05:05 2014
@@ -103,12 +103,12 @@ protected:
 
 public:
 	/** constructs the object. Everything written into the stream through the XOutputStream methods will be forwarded
-		to the sequence, reallocating it if neccessary. Writing will start at offset 0 within the sequence.
+		to the sequence, reallocating it if necessary. Writing will start at offset 0 within the sequence.
 		@param		_rSeq				a reference to the sequence which will be used for output.
 										The caller is responsible for taking care of the lifetime of the stream
 										object and the sequence. If you're in doubt about this, use <code>closeOutput</code>
 										before destroying the sequence
-		@param		_nResizeFactor		the factor which is used for resizing the sequence when neccessary. In every
+		@param		_nResizeFactor		the factor which is used for resizing the sequence when necessary. In every
 										resize step, the new sequence size will be calculated by multiplying the current
 										size with this factor, rounded off to the next multiple of 4.
 		@param		_nMinimumResize		the minmal number of bytes which is additionally allocated on resizing

Modified: openoffice/trunk/main/comphelper/inc/comphelper/sequence.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/comphelper/inc/comphelper/sequence.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/comphelper/inc/comphelper/sequence.hxx (original)
+++ openoffice/trunk/main/comphelper/inc/comphelper/sequence.hxx Tue Apr 29 19:05:05 2014
@@ -43,7 +43,7 @@ namespace comphelper
 
 	//-------------------------------------------------------------------------
 	/** search the given string within the given sequence, return the positions where it was found.
-		if _bOnlyFirst is sal_True, only the first occurence will be returned.
+		if _bOnlyFirst is sal_True, only the first occurrence will be returned.
 	*/
 	COMPHELPER_DLLPUBLIC staruno::Sequence<sal_Int16> findValue(const staruno::Sequence< ::rtl::OUString >& _rList, const ::rtl::OUString& _rValue, sal_Bool _bOnlyFirst = sal_False);
 

Modified: openoffice/trunk/main/comphelper/inc/comphelper/sequenceashashmap.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/comphelper/inc/comphelper/sequenceashashmap.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/comphelper/inc/comphelper/sequenceasvector.hxx (original)
+++ openoffice/trunk/main/comphelper/inc/comphelper/sequenceasvector.hxx Tue Apr 29 19:05:05 2014
@@ -48,7 +48,7 @@ namespace comphelper{
 
     @descr  That provides the possibility to modify
             sequences very easy ...
-            Of course this can be usefull only, if
+            Of course this can be useful only, if
             count of modifications is high, so copying
             of the sequence make sense!
  */

Modified: openoffice/trunk/main/comphelper/inc/comphelper/string.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/comphelper/inc/comphelper/string.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/comphelper/inc/comphelper/string.hxx (original)
+++ openoffice/trunk/main/comphelper/inc/comphelper/string.hxx Tue Apr 29 19:05:05 2014
@@ -70,14 +70,14 @@ COMPHELPER_DLLPUBLIC rtl::OUString searc
     rtl::OUString const & to, sal_Int32 beginAt = 0,
     sal_Int32 * replacedAt = NULL);
 
-/** replaces, in the given source string, all occurences of a given ASCII pattern
+/** replaces, in the given source string, all occurrences of a given ASCII pattern
     with another ASCII pattern
 */
 COMPHELPER_DLLPUBLIC ::rtl::OUString searchAndReplaceAllAsciiWithAscii(
     const ::rtl::OUString& source, const sal_Char* from, const sal_Char* to,
     const sal_Int32 beginAt = 0 );
 
-/** does an in-place replacement of the first occurance of a sub string with
+/** does an in-place replacement of the first occurrence of a sub string with
     another string
 
     @param source

Modified: openoffice/trunk/main/comphelper/source/container/embeddedobjectcontainer.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/comphelper/source/container/embeddedobjectcontainer.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/comphelper/source/container/enumerablemap.cxx (original)
+++ openoffice/trunk/main/comphelper/source/container/enumerablemap.cxx Tue Apr 29 19:05:05 2014
@@ -344,7 +344,7 @@ namespace comphelper
         }
 
     private:
-        // sicne we share our mutex with the main map, we need to keep it alive as long as we live
+        // since we share our mutex with the main map, we need to keep it alive as long as we live
         Reference< XInterface >     m_xKeepMapAlive;
         ::std::auto_ptr< MapData >  m_pMapDataCopy;
         MapEnumerator               m_aEnumerator;

Modified: openoffice/trunk/main/comphelper/source/misc/accessiblecontexthelper.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/comphelper/source/misc/accessiblecontexthelper.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/comphelper/source/misc/accessiblecontexthelper.cxx (original)
+++ openoffice/trunk/main/comphelper/source/misc/accessiblecontexthelper.cxx Tue Apr 29 19:05:05 2014
@@ -216,7 +216,7 @@ namespace comphelper
 	{
 		// TODO: this whole method (as well as the class AccessibleEventBuffer) should be removed
 		// The reasons why they have been introduces id that we needed to collect a set of events
-		// before notifying them alltogether (after releasing our mutex). With the other
+		// before notifying them altogether (after releasing our mutex). With the other
 		// NotifyAccessibleEvent being asynchronous now, this should not be necessary anymore
 		// - clients could use the other version now.
 

Modified: openoffice/trunk/main/comphelper/source/misc/asyncnotification.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/comphelper/source/misc/asyncnotification.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/comphelper/source/misc/asyncnotification.cxx (original)
+++ openoffice/trunk/main/comphelper/source/misc/asyncnotification.cxx Tue Apr 29 19:05:05 2014
@@ -249,7 +249,7 @@ namespace comphelper
     void SAL_CALL AsyncEventNotifier::onTerminated()
     {
         AsyncEventNotifier_TBASE::onTerminated();
-        // when we were started (->run), we aquired ourself. Release this now
+        // when we were started (->run), we acquired ourself. Release this now
         // that we were finally terminated
         release();
     }

Modified: openoffice/trunk/main/comphelper/source/misc/locale.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/comphelper/source/misc/locale.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/comphelper/source/misc/locale.cxx (original)
+++ openoffice/trunk/main/comphelper/source/misc/locale.cxx Tue Apr 29 19:05:05 2014
@@ -426,7 +426,7 @@ void Locale::setVariant(const ::rtl::OUS
 /* Attention: Use own interface methods to set the
    different parts of this locale. Because the
    check the incoming value and throw an exception
-   automaticly ...
+   automatically ...
  */
 void Locale::fromISO(const ::rtl::OUString& sISO)
     throw(Locale::MalFormedLocaleException)
@@ -511,7 +511,7 @@ sal_Bool Locale::similar(const Locale& a
     Locale aReference(sReferenceISO);
     
     // Note: The same language or "en"/"en-US" should be preferred as fallback.
-    // On the other side some localized variables doesnt use localzation in real.
+    // On the other side some localized variables doesn't use localzation in real.
     // May be the use a "fix" value only ... marked as X-DEFAULT or X-NOTRANSLATE.
     // At least it can be discussed, if any language is a valid fallback ...
     // But in case some office functionality depends on that (that means real functionality instead

Modified: openoffice/trunk/main/comphelper/source/misc/mediadescriptor.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/comphelper/source/misc/mediadescriptor.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/comphelper/source/misc/numberedcollection.cxx (original)
+++ openoffice/trunk/main/comphelper/source/misc/numberedcollection.cxx Tue Apr 29 19:05:05 2014
@@ -213,7 +213,7 @@ void SAL_CALL NumberedCollection::releas
     ::sal_Int32                  c = (::sal_Int32)m_lComponents.size ();
     ::sal_Int32                  i = 1;
 
-    // c cant be less then 0 ... otherwhise hash.size() has an error :-)
+    // c can't be less than 0 ... otherwise hash.size() has an error :-)
     // But we need at least n+1 numbers here.
 	c += 1;
 

Modified: openoffice/trunk/main/comphelper/source/misc/proxyaggregation.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/comphelper/source/misc/proxyaggregation.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/comphelper/source/misc/proxyaggregation.cxx (original)
+++ openoffice/trunk/main/comphelper/source/misc/proxyaggregation.cxx Tue Apr 29 19:05:05 2014
@@ -58,7 +58,7 @@ namespace comphelper
 		// then the proxy itself
 		if ( xFactory.is() )
 		{
-			{ // i36686 OJ: achieve the desctruction of the tempoary -> otherwise it leads to _rRefCount -= 2
+			{ // i36686 OJ: achieve the destruction of the tempoary -> otherwise it leads to _rRefCount -= 2
 				m_xProxyAggregate = xFactory->createProxy( _rxComponent );
 			}
             if ( m_xProxyAggregate.is() )

Modified: openoffice/trunk/main/comphelper/source/misc/scopeguard.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/comphelper/source/misc/scopeguard.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/comphelper/source/misc/scopeguard.cxx (original)
+++ openoffice/trunk/main/comphelper/source/misc/scopeguard.cxx Tue Apr 29 19:05:05 2014
@@ -44,11 +44,11 @@ ScopeGuard::~ScopeGuard()
                 OSL_ENSURE(
                     false, rtl::OUStringToOString(
                         rtl::OUString( RTL_CONSTASCII_USTRINGPARAM(
-                                           "UNO exception occured: ") ) +
+                                           "UNO exception occurred: ") ) +
                         exc.Message, RTL_TEXTENCODING_UTF8 ).getStr() );
             }
             catch (...) {
-                OSL_ENSURE( false, "unknown exception occured!" );
+                OSL_ENSURE( false, "unknown exception occurred!" );
             }
         }
         else

Modified: openoffice/trunk/main/comphelper/source/misc/sequenceashashmap.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/comphelper/source/misc/sequenceashashmap.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/comphelper/source/misc/sequenceashashmap.cxx (original)
+++ openoffice/trunk/main/comphelper/source/misc/sequenceashashmap.cxx Tue Apr 29 19:05:05 2014
@@ -130,7 +130,7 @@ void SequenceAsHashMap::operator<<(const
                 (!lP.Value.hasValue())
                )
                 throw css::beans::IllegalTypeException(
-                        ::rtl::OUString::createFromAscii("PropertyValue struct contains no usefull informations."),
+                        ::rtl::OUString::createFromAscii("PropertyValue struct contains no useful informations."),
                         css::uno::Reference< css::uno::XInterface >());
             (*this)[lP.Name] = lP.Value;                    
             continue;
@@ -144,7 +144,7 @@ void SequenceAsHashMap::operator<<(const
                 (!lN.Value.hasValue())
                )
                 throw css::beans::IllegalTypeException(
-                        ::rtl::OUString::createFromAscii("NamedValue struct contains no usefull informations."),
+                        ::rtl::OUString::createFromAscii("NamedValue struct contains no useful informations."),
                         css::uno::Reference< css::uno::XInterface >());
             (*this)[lN.Name] = lN.Value;                    
             continue;

Modified: openoffice/trunk/main/configure.in
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/configure.in?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/configure.in (original)
+++ openoffice/trunk/main/configure.in Tue Apr 29 19:05:05 2014
@@ -362,7 +362,7 @@ AC_ARG_ENABLE(randr-link,
                            open it at runtime
 ],,enable_randr_link=yes)
 AC_ARG_WITH(bundled-extension-blobs,
-[  --with-bundled-extension-blobs Whitespace seperated list of files in the tarball directory
+[  --with-bundled-extension-blobs Whitespace separated list of files in the tarball directory
                           that are to be bundled as-is for installation as extensions
                           at the first program start. Make sure to only bundle extensions
                           which can be installed without requiring a license dialog
@@ -370,7 +370,7 @@ AC_ARG_WITH(bundled-extension-blobs,
                           files LICENSE_aggregated and NOTICE_aggregated accordingly
 ],,)
 #AC_ARG_WITH(bundled-prereg-extensions,
-#[  --with-bundled-prereg-extensions Whitespace seperated list of files in the tarball directory that
+#[  --with-bundled-prereg-extensions Whitespace separated list of files in the tarball directory that
 #                          are to be bundled as pre-registered extensions. Make sure to only bundle
 #                          extensions which can be installed without requiring a license dialog
 #],,)
@@ -3656,7 +3656,7 @@ if test "z$enable_odk" = "z" -o "$enable
       save_CPPFLAGS=$CPPFLAGS
       CXXFLAGS="$CXXFLAGS -I$JAVA_HOME/include"
       CPPFLAGS="$CPPFLAGS -I$JAVA_HOME/include"
-      # LIBS contains -lcrypt etc due to teh AC_CHECK_LIBS which obviously
+      # LIBS contains -lcrypt etc due to the AC_CHECK_LIBS which obviously
       # do not make sense here (and 'd make the check fail)
       save_LIBS=$LIBS
       LIBS=""
@@ -3911,7 +3911,7 @@ dnl Checks for a MacOS platform SDK comp
 dnl ===================================================================
 if test  "$_os" = "Darwin"; then
    sdk_target=10.7
-   AC_MSG_CHECKING([checking SDK compatiblity with OSX $sdk_target])
+   AC_MSG_CHECKING([checking SDK compatibility with OSX $sdk_target])
 
    sdk_minor=`echo $sdk_target | cut -d"." -f2`
 
@@ -5464,7 +5464,7 @@ if test \( "$_os" = "WINNT" \) ; then
         fi
         AC_MSG_NOTICE([found atls.lib in "$ATL_LIB"? "$HAVE_ATL_LIB"])
 
-        dnl TODO check also MFC libraries, they seem to have diferent names
+        dnl TODO check also MFC libraries, they seem to have different names
         dnl mfc42.lib mfc90.lib
         if test -d "$MFC_LIB"; then
             HAVE_MFC_LIB="yes"

Modified: openoffice/trunk/main/connectivity/inc/connectivity/FValue.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/connectivity/inc/connectivity/FValue.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/connectivity/inc/connectivity/FValue.hxx (original)
+++ openoffice/trunk/main/connectivity/inc/connectivity/FValue.hxx Tue Apr 29 19:05:05 2014
@@ -251,7 +251,7 @@ namespace connectivity
 		ORowSetValue& operator=(const ::rtl::OUString& _rRH);
 		// the type isn't set it will be set to VARCHAR if the type is different change it
 		ORowSetValue& operator=(const ::com::sun::star::uno::Sequence<sal_Int8>& _rRH);
-		// we the possiblity to save a any for bookmarks
+		// we the possibility to save a any for bookmarks
 		ORowSetValue& operator=(const ::com::sun::star::uno::Any& _rAny);
 
 		operator sal_Bool() const	{	return isNull() ? sal_False : getBool();	}

Modified: openoffice/trunk/main/connectivity/inc/connectivity/dbmetadata.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/connectivity/inc/connectivity/dbmetadata.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/connectivity/inc/connectivity/dbmetadata.hxx (original)
+++ openoffice/trunk/main/connectivity/inc/connectivity/dbmetadata.hxx Tue Apr 29 19:05:05 2014
@@ -144,7 +144,7 @@ namespace dbtools
         */
         bool shouldEscapeDateTime() const;
 
-        /** auto increment columns should be automaticly used as primary key.
+        /** auto increment columns should be automatically used as primary key.
         */
         bool isAutoIncrementPrimaryKey() const;
 

Modified: openoffice/trunk/main/connectivity/inc/connectivity/dbtools.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/connectivity/inc/connectivity/dbtools.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/connectivity/inc/connectivity/dbtools.hxx (original)
+++ openoffice/trunk/main/connectivity/inc/connectivity/dbtools.hxx Tue Apr 29 19:05:05 2014
@@ -255,7 +255,7 @@ namespace dbtools
 			If (and only if) <arg>CommandType</arg> is CommandType.COMMAND, the fields collection which is returned
 			by this function here is a temporary object. It is kept alive by another object, which is to be
 			created temporarily, too. To ensure that the fields you get are valid as long as you need them,
-			the owner which controls their life time is transfered to this parameter upon return.<br/>
+			the owner which controls their life time is transferred to this parameter upon return.<br/>
 
 			Your fields live as long as this component lives.<br/>
 
@@ -330,7 +330,7 @@ namespace dbtools
         const StandardSQLState _eSQLState = SQL_ERROR_UNSPECIFIED,
         const sal_Int32 _nErrorCode = 0);
 
-	/** search the parent hierachy for a data source.
+	/** search the parent hierarchy for a data source.
 	*/
 	OOO_DLLPUBLIC_DBTOOLS ::com::sun::star::uno::Reference< ::com::sun::star::sdbc::XDataSource> findDataSource(const ::com::sun::star::uno::Reference< ::com::sun::star::uno::XInterface >& _xParent);
 
@@ -363,7 +363,7 @@ namespace dbtools
         @param _pAsciiSettingsName
             the ASCII name of the setting to obtain
         @param _rSettingsValue
-            the value of the setting, upon successfull return
+            the value of the setting, upon successful return
 
         @return
             <FALSE/> if the setting is not present in the <member scope="com::sun::star::sdb">DataSource::Info</member>
@@ -610,7 +610,7 @@ namespace dbtools
 							const ::com::sun::star::uno::Reference< ::com::sun::star::task::XInteractionHandler >& _rxHandler,
                             const ::std::bit_vector& _aParametersSet = ::std::bit_vector());
 
-	/** call the appropiate set method for the specific sql type @see com::sun::star::sdbc::DataType
+	/** call the appropriate set method for the specific sql type @see com::sun::star::sdbc::DataType
 		@param	_xParams		the parameters where to set the value
 		@param	parameterIndex	the index of the parameter, 1 based
 		@param	x				the value to set
@@ -624,7 +624,7 @@ namespace dbtools
 							sal_Int32 sqlType,
 							sal_Int32 scale=0) throw(::com::sun::star::sdbc::SQLException, ::com::sun::star::uno::RuntimeException);
 
-	/** call the appropiate set method for the specific sql type @see com::sun::star::sdbc::DataType
+	/** call the appropriate set method for the specific sql type @see com::sun::star::sdbc::DataType
 		@param	_xParams		the parameters where to set the value
 		@param	parameterIndex	the index of the parameter, 1 based
 		@param	x				the value to set

Modified: openoffice/trunk/main/connectivity/inc/connectivity/parameters.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/connectivity/inc/connectivity/parameters.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/connectivity/inc/connectivity/parameters.hxx (original)
+++ openoffice/trunk/main/connectivity/inc/connectivity/parameters.hxx Tue Apr 29 19:05:05 2014
@@ -84,7 +84,7 @@ namespace dbtools
             /// the column object for this parameter, as returned by the query composer
             ::com::sun::star::uno::Reference< ::com::sun::star::beans::XPropertySet >
                                         xComposerColumn;
-            /// the indicies of inner parameters which need to be filled when this concrete parameter is set
+            /// the indices of inner parameters which need to be filled when this concrete parameter is set
             ::std::vector< sal_Int32 >  aInnerIndexes;
 
             /// default ctor
@@ -267,7 +267,7 @@ namespace dbtools
             @param _rxComponent
                 the database component to initialize from. Must not be <NULL/>
             @return
-                <TRUE/> if and only if the initialization was successfull
+                <TRUE/> if and only if the initialization was successful
 
             @postcond
                 if and only if <TRUE/> is returned, then <member>m_xInnerParamColumns</member> contains the collection of

Modified: openoffice/trunk/main/connectivity/inc/connectivity/sdbcx/VCatalog.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/connectivity/inc/connectivity/sdbcx/VCatalog.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/connectivity/inc/connectivity/sdbcx/VCatalog.hxx (original)
+++ openoffice/trunk/main/connectivity/inc/connectivity/sdbcx/VCatalog.hxx Tue Apr 29 19:05:05 2014
@@ -83,7 +83,7 @@ namespace connectivity
 			*/
 			virtual ::rtl::OUString buildName(	const ::com::sun::star::uno::Reference< ::com::sun::star::sdbc::XRow >& _xRow);
 
-			/** fills a vector with the nescessary names which can be used in combination with the collections.
+			/** fills a vector with the necessary names which can be used in combination with the collections.
 				For each row buildName will be called.
 				@param	_xResult
 					The resultset which should be used to fill the names. Will be disposed after return and set to NULL.

Modified: openoffice/trunk/main/connectivity/inc/connectivity/sqlerror.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/connectivity/inc/connectivity/sqlerror.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/connectivity/inc/connectivity/sqlerror.hxx (original)
+++ openoffice/trunk/main/connectivity/inc/connectivity/sqlerror.hxx Tue Apr 29 19:05:05 2014
@@ -173,7 +173,7 @@ namespace connectivity
                 the ErrorCondition which hit you
 
             @param  _rxContext
-                the context in which the error occured. This will be filled in as
+                the context in which the error occurred. This will be filled in as
                 <member scope="com::sun::star::uno">Exception::Context</member> member.
 
             @param _rParamValue1
@@ -210,7 +210,7 @@ namespace connectivity
 
             Note: You should prefer the version of <type>raiseException</type> which takes
             an additional <type>Context</type> parameter, since this allows clients of your
-            exception to examine where the error occured.
+            exception to examine where the error occurred.
 
             @param  _eCondition
                 the ErrorCondition which hit you
@@ -248,7 +248,7 @@ namespace connectivity
                 the ErrorCondition which hit you
 
             @param  _rxContext
-                the context in which the error occured. This will be filled in as
+                the context in which the error occurred. This will be filled in as
                 <member scope="com::sun::star::uno">Exception::Context</member> member.
 
             @param _rExceptionType
@@ -294,7 +294,7 @@ namespace connectivity
                 the ErrorCondition which hit you
 
             @param  _rxContext
-                the context in which the error occured. This will be filled in as
+                the context in which the error occurred. This will be filled in as
                 <member scope="com::sun::star::uno">Exception::Context</member> member.
 
             @param _rParamValue1

Modified: openoffice/trunk/main/connectivity/inc/connectivity/sqliterator.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/connectivity/inc/connectivity/sqliterator.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/connectivity/inc/connectivity/sqlnode.hxx (original)
+++ openoffice/trunk/main/connectivity/inc/connectivity/sqlnode.hxx Tue Apr 29 19:05:05 2014
@@ -301,7 +301,7 @@ namespace connectivity
                 too, to check whether they contain nested sub queries.
 
             @param _pErrorHolder
-                takes the error which occured while generating the statement, if any. Might be <NULL/>,
+                takes the error which occurred while generating the statement, if any. Might be <NULL/>,
                 in this case the error is not reported back, and can only be recognized by examing the
                 return value.
 
@@ -412,7 +412,7 @@ namespace connectivity
 											::rtl::OUString &_rTable
                                             ,const ::com::sun::star::uno::Reference< ::com::sun::star::sdbc::XDatabaseMetaData >& _xMetaData);
 
-		// susbtitute all occurences of :var or [name] into the dynamic parameter ?
+		// susbtitute all occurrences of :var or [name] into the dynamic parameter ?
 		// _pNode will be modified if parameters exists
 		static void substituteParameterNames(OSQLParseNode* _pNode);
 

Modified: openoffice/trunk/main/connectivity/inc/connectivity/virtualdbtools.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/connectivity/inc/connectivity/virtualdbtools.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/connectivity/inc/connectivity/virtualdbtools.hxx (original)
+++ openoffice/trunk/main/connectivity/inc/connectivity/virtualdbtools.hxx Tue Apr 29 19:05:05 2014
@@ -91,7 +91,7 @@ namespace comphelper {
 	instance, which is acquired <em>once</em>.</p>
 	@return
 		a pointer to an object implementing the IDataAccessToolsFactory interface,
-		aquired exactly <em>once</em>.
+		acquired exactly <em>once</em>.
 */
 extern "C" OOO_DLLPUBLIC_DBTOOLS void* SAL_CALL createDataAccessToolsFactory();
 

Modified: openoffice/trunk/main/connectivity/qa/complex/connectivity/JdbcLongVarCharTest.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/connectivity/qa/complex/connectivity/JdbcLongVarCharTest.java?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/connectivity/qa/complex/connectivity/JdbcLongVarCharTest.java (original)
+++ openoffice/trunk/main/connectivity/qa/complex/connectivity/JdbcLongVarCharTest.java Tue Apr 29 19:05:05 2014
@@ -117,7 +117,7 @@ public class JdbcLongVarCharTest extends
         }
         catch (java.lang.Exception e)
         {
-            System.out.println("== Exception occured while testing ==");
+            System.out.println("== Exception occurred while testing ==");
             e.printStackTrace();
         } finally
         {

Modified: openoffice/trunk/main/connectivity/qa/complex/connectivity/hsqldb/DatabaseMetaData.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/connectivity/qa/complex/connectivity/hsqldb/DatabaseMetaData.java?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/connectivity/qa/complex/connectivity/hsqldb/DatabaseMetaData.java (original)
+++ openoffice/trunk/main/connectivity/qa/complex/connectivity/hsqldb/DatabaseMetaData.java Tue Apr 29 19:05:05 2014
@@ -68,7 +68,7 @@ public class DatabaseMetaData {
         } catch( java.lang.IllegalAccessException ex ) {
             assure("IllegalAccessException!",false);
         } catch( SQLException ex ) {
-            assure("SQLException occured: " + ex.getMessage() ,false);
+            assure("SQLException occurred: " + ex.getMessage() ,false);
         } catch( java.lang.reflect.InvocationTargetException ex ) {
             assure("IllegalAccessException!",false);
         } finally {

Modified: openoffice/trunk/main/connectivity/source/commontools/TSkipDeletedSet.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/connectivity/source/commontools/TSkipDeletedSet.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/connectivity/source/commontools/TSkipDeletedSet.cxx (original)
+++ openoffice/trunk/main/connectivity/source/commontools/TSkipDeletedSet.cxx Tue Apr 29 19:05:05 2014
@@ -61,7 +61,7 @@ sal_Bool OSkipDeletedSet::skipDeleted(IR
 			nDelOffset = 1;
 			break;
 		case IResultSetHelper::LAST:
-			eDelPosition = IResultSetHelper::PRIOR; // lsat row is invalid so position before
+			eDelPosition = IResultSetHelper::PRIOR; // last row is invalid so position before
 			nDelOffset = 1;
 			break;
 		case IResultSetHelper::RELATIVE:

Modified: openoffice/trunk/main/connectivity/source/commontools/parameters.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/connectivity/source/commontools/parameters.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/connectivity/source/commontools/parameters.cxx (original)
+++ openoffice/trunk/main/connectivity/source/commontools/parameters.cxx Tue Apr 29 19:05:05 2014
@@ -192,7 +192,7 @@ namespace dbtools
         }
 
         // we need to map the parameter names (which is all we get from the 's
-        // MasterFields property) to indicies, which are needed by the XParameters
+        // MasterFields property) to indices, which are needed by the XParameters
         // interface of the row set)
         Reference<XPropertySet> xParam;
         for ( sal_Int32 i = 0; i < m_nInnerCount; ++i )
@@ -205,7 +205,7 @@ namespace dbtools
                 ::rtl::OUString sName;
                 xParam->getPropertyValue( OMetaConnection::getPropMap().getNameByIndex(PROPERTY_ID_NAME) ) >>= sName;
 
-                // only append additonal paramters when they are not already in the list
+                // only append additional parameters when they are not already in the list
                 ParameterInformation::iterator aExistentPos = m_aParameterInformation.find( sName );
                 OSL_ENSURE( !_bSecondRun || ( aExistentPos != m_aParameterInformation.end() ),
                     "ParameterManager::collectInnerParameters: the parameter information should already exist in the second run!" );
@@ -479,9 +479,9 @@ namespace dbtools
             ( nSmallestIndexLinkedByColumnName > nLargestIndexNotLinkedByColumnName ),
             "ParameterManager::createOuterParameters: inconsistency!" );
 
-        // for the master-detail links, where the detail field denoted a column name, we created an addtional ("artificial")
+        // for the master-detail links, where the detail field denoted a column name, we created an additional ("artificial")
         // filter, and *appended* it to all other (potentially) existing filters of the row set. This means that the indexes
-        // for the parameters resulting from the artifical filter should be larger than any other parameter index, and this
+        // for the parameters resulting from the artificial filter should be larger than any other parameter index, and this
         // is what the assertion checks.
         // If the assertion fails, then we would need another handling for the "parameters visited" flags, since they're based
         // on parameter indexes *without* the artificial filter (because this filter is not visible from the outside).
@@ -561,7 +561,7 @@ namespace dbtools
 			Any aParamType, aScale, aValue;
 
             // loop through all master fields. For each of them, get the respective column from the
-            // parent , and forward it's current value as paramter value to the (inner) row set
+            // parent , and forward it's current value as parameter value to the (inner) row set
             for ( sal_Int32 i = 0; i < nMasterLen; ++i, ++pMasterFields, ++pDetailFields )
 			{
                 // does the name denote a valid column in the parent?

Modified: openoffice/trunk/main/connectivity/source/cpool/ZConnectionPool.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/connectivity/source/cpool/ZConnectionPool.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/connectivity/source/cpool/ZConnectionPool.hxx (original)
+++ openoffice/trunk/main/connectivity/source/cpool/ZConnectionPool.hxx Tue Apr 29 19:05:05 2014
@@ -68,7 +68,7 @@ namespace connectivity
 	typedef struct 
 	{
 		TPooledConnections	aConnections;
-		sal_Int32			nALiveCount; // will be decremented everytime a time says to, when will reach zero the pool will be deleted
+		sal_Int32			nALiveCount; // will be decremented every time a time says to, when will reach zero the pool will be deleted
 	} TConnectionPool;
 
 	struct TDigestHolder

Modified: openoffice/trunk/main/connectivity/source/cpool/ZPoolCollection.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/connectivity/source/cpool/ZPoolCollection.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/connectivity/source/cpool/ZPoolCollection.hxx (original)
+++ openoffice/trunk/main/connectivity/source/cpool/ZPoolCollection.hxx Tue Apr 29 19:05:05 2014
@@ -53,7 +53,7 @@ namespace connectivity
 										::com::sun::star::beans::XPropertyChangeListener
 										>	OPoolCollection_Base;
 
-	/// OPoolCollection: controll the whole connection pooling for oo
+	/// OPoolCollection: control the whole connection pooling for oo
 	class OPoolCollection : public OPoolCollection_Base
 	{
 		

Modified: openoffice/trunk/main/connectivity/source/drivers/ado/ADatabaseMetaDataResultSet.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/connectivity/source/drivers/ado/ADatabaseMetaDataResultSet.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/connectivity/source/drivers/ado/ADatabaseMetaDataResultSet.cxx (original)
+++ openoffice/trunk/main/connectivity/source/drivers/ado/ADatabaseMetaDataResultSet.cxx Tue Apr 29 19:05:05 2014
@@ -147,7 +147,7 @@ Reference< ::com::sun::star::io::XInputS
 	WpADOField aField = ADOS::getField(m_pRecordSet,columnIndex);
 	if((aField.GetAttributes() & adFldLong) == adFldLong)
 	{
-		//Copy the data only upto the Actual Size of Field.
+		//Copy the data only up to the Actual Size of Field.
 		sal_Int32 nSize = aField.GetActualSize();
 		Sequence<sal_Int8> aData(nSize);
 		long index = 0;

Modified: openoffice/trunk/main/connectivity/source/drivers/ado/AResultSet.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/connectivity/source/drivers/ado/AResultSet.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/connectivity/source/drivers/ado/AResultSet.cxx (original)
+++ openoffice/trunk/main/connectivity/source/drivers/ado/AResultSet.cxx Tue Apr 29 19:05:05 2014
@@ -179,7 +179,7 @@ Reference< ::com::sun::star::io::XInputS
 
 	if((aField.GetAttributes() & adFldLong) == adFldLong)
 	{
-		//Copy the data only upto the Actual Size of Field.
+		//Copy the data only up to the Actual Size of Field.
 		sal_Int32 nSize = aField.GetActualSize();
 		Sequence<sal_Int8> aData(nSize);
 		long index = 0;

Modified: openoffice/trunk/main/connectivity/source/drivers/dbase/DTable.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/connectivity/source/drivers/dbase/DTable.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/connectivity/source/drivers/dbase/DTable.cxx (original)
+++ openoffice/trunk/main/connectivity/source/drivers/dbase/DTable.cxx Tue Apr 29 19:05:05 2014
@@ -2290,7 +2290,7 @@ void ODbaseTable::alterColumn(sal_Int32 
 	}
 	catch(const Exception&)
 	{
-		OSL_ENSURE(0,"ODbaseTable::alterColumn: Exception occured!");
+		OSL_ENSURE(0,"ODbaseTable::alterColumn: Exception occurred!");
 		throw;
 	}
 }

Modified: openoffice/trunk/main/connectivity/source/drivers/evoab2/NDatabaseMetaData.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/connectivity/source/drivers/evoab2/NDatabaseMetaData.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/connectivity/source/drivers/evoab2/NDatabaseMetaData.cxx (original)
+++ openoffice/trunk/main/connectivity/source/drivers/evoab2/NDatabaseMetaData.cxx Tue Apr 29 19:05:05 2014
@@ -628,7 +628,7 @@ sal_Bool SAL_CALL OEvoabDatabaseMetaData
 // -------------------------------------------------------------------------
 sal_Bool SAL_CALL OEvoabDatabaseMetaData::isReadOnly(  ) throw(SQLException, RuntimeException)
 {
-    // For now definately read-only, no support for update/delete
+    // For now definitely read-only, no support for update/delete
 	return sal_True;
 }
 // -------------------------------------------------------------------------

Modified: openoffice/trunk/main/connectivity/source/drivers/evoab2/NDriver.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/connectivity/source/drivers/evoab2/NDriver.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/connectivity/source/drivers/evoab2/NDriver.hxx (original)
+++ openoffice/trunk/main/connectivity/source/drivers/evoab2/NDriver.hxx Tue Apr 29 19:05:05 2014
@@ -31,7 +31,7 @@
 #include <osl/module.h>
 
 #define EVOAB_EVOLUTION_SCHEMA	"evolution"
-/*In Future, when seperate schema is required for ldap, groupwise*/
+/*In Future, when separate schema is required for ldap, groupwise*/
 #define EVOAB_LDAP_SCHEMA	"ldap" 
 #define EVOAB_GWISE_SCHEMA	"groupwise"
 

Modified: openoffice/trunk/main/connectivity/source/drivers/evoab2/NStatement.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/connectivity/source/drivers/evoab2/NStatement.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/connectivity/source/drivers/evoab2/NStatement.cxx (original)
+++ openoffice/trunk/main/connectivity/source/drivers/evoab2/NStatement.cxx Tue Apr 29 19:05:05 2014
@@ -423,7 +423,7 @@ EBookQuery *OCommonStatement::whereAnaly
             m_pConnection->throwGenericSQLException(STR_QUERY_NOT_LIKE_TOO_COMPLEX,*this);
 		}
 		else if( (aMatchString.indexOf ( WILDCARD ) == aMatchString.lastIndexOf ( WILDCARD ) ) )
-		{   // One occurance of '%'  matches...
+		{   // One occurrence of '%'  matches...
             if ( aMatchString.indexOf ( WILDCARD ) == 0 )
 				pResult = createTest( aColumnName, E_BOOK_QUERY_ENDS_WITH, aMatchString.copy( 1 ) );
             else if ( aMatchString.indexOf ( WILDCARD ) == aMatchString.getLength() - 1 )

Modified: openoffice/trunk/main/connectivity/source/drivers/file/FPreparedStatement.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/connectivity/source/drivers/file/FPreparedStatement.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/connectivity/source/drivers/file/FPreparedStatement.cxx (original)
+++ openoffice/trunk/main/connectivity/source/drivers/file/FPreparedStatement.cxx Tue Apr 29 19:05:05 2014
@@ -423,7 +423,7 @@ Reference<XResultSet> OPreparedStatement
 	m_pResultSet->clear();
 	Reference<XResultSet> xRs(m_pResultSet);
 
-	// check if we got enough paramters
+	// check if we got enough parameters
 	if ( (m_aParameterRow.isValid() && ( m_aParameterRow->get().size() -1 ) < m_xParamColumns->get().size()) ||
 		 (m_xParamColumns.isValid() && !m_aParameterRow.isValid() && !m_aParameterRow->get().empty()) )
          m_pConnection->throwGenericSQLException(STR_INVALID_PARA_COUNT,*this);
--- openoffice/trunk/main/comphelper/inc/comphelper/sequenceashashmap.hxx (original)
+++ openoffice/trunk/main/comphelper/inc/comphelper/sequenceashashmap.hxx Tue Apr 29 19:05:05 2014
@@ -109,7 +109,7 @@ class COMPHELPER_DLLPUBLIC SequenceAsHas
         SequenceAsHashMap(const ::com::sun::star::uno::Sequence< ::com::sun::star::beans::NamedValue >& lSource);
 
         //---------------------------------------
         /** @short  not realy used but maybe usefull :-)
          */
         ~SequenceAsHashMap();
 
@@ -254,7 +254,7 @@ class COMPHELPER_DLLPUBLIC SequenceAsHas
                     specified default value otherwhise.
 
             @descr  If a value should be extracted only in case
-                    the requsted property exists realy (without creating
+                    the requsted property exists really (without creating
                     of new items as it the index operator of a
                     has_map does!) this method can be used.
 
@@ -292,7 +292,7 @@ class COMPHELPER_DLLPUBLIC SequenceAsHas
                     does not already exist.
 
             @descr  To check if the property already exists only
-                    her name is used for compare. Its value isnt
+                    her name is used for compare. Its value isn't
                     checked!
 
             @param  sKey
@@ -356,18 +356,18 @@ class COMPHELPER_DLLPUBLIC SequenceAsHas
                     the current content of this instance.
 
             @descr  Because the content of STL container
-                    cant be analyzed easy, such dump function
-                    seem to be usefull.
+                    can't be analyzed easy, such dump function
+                    seems to be useful.
                     Of course its available in debug versions
                     only.
 
             @param  pFileName
                     a system file name.
-                    (doesnt matter if relativ or absolute)
+                    (doesn't matter if relativ or absolute)
 
             @param  pComment
                     used to mark the dump inside the same log file.
-                    Can be usefull to analyze changes of this
+                    Can be useful to analyze changes of this
                     hash map due to the parts of an operation.
          */
         #if OSL_DEBUG_LEVEL > 1
@@ -109,7 +109,7 @@ class COMPHELPER_DLLPUBLIC SequenceAsHas
 
         //---------------------------------------
-        /** @short  not realy used but maybe usefull :-)
+        /** @short  not really used but maybe useful :-)
          */
         ~SequenceAsHashMap();

Modified: openoffice/trunk/main/comphelper/inc/comphelper/sequenceasvector.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/comphelper/inc/comphelper/sequenceasvector.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/comphelper/source/container/embeddedobjectcontainer.cxx (original)
+++ openoffice/trunk/main/comphelper/source/container/embeddedobjectcontainer.cxx Tue Apr 29 19:05:05 2014
@@ -445,7 +445,7 @@ void EmbeddedObjectContainer::AddEmbedde
     uno::Reference < container::XNameAccess > xAccess( pImpl->mxStorage, uno::UNO_QUERY );
     uno::Reference < embed::XEmbedPersist > xEmb( xObj, uno::UNO_QUERY );
 	uno::Reference < embed::XLinkageSupport > xLink( xEmb, uno::UNO_QUERY );
-	// if the object has a persistance and the object is not a link than it must have persistence entry in the storage
+	// if the object has a persistence and the object is not a link than it must have persistence entry in the storage
     OSL_ENSURE( !( xEmb.is() && ( !xLink.is() || !xLink->isLink() ) ) || xAccess->hasByName(rName),
 					"Added element not in storage!" );
 #endif
@@ -751,7 +751,7 @@ uno::Reference < embed::XEmbeddedObject 
     if ( rName.isEmpty() )
         rName = CreateUniqueObjectName();
 
 	// objects without persistance are not really stored by the method
    	if ( xObj.is() && StoreEmbeddedObject( xObj, rName, sal_True ) )
 	{
         xResult = Get_Impl( rName, xObj);
@@ -798,7 +798,7 @@ uno::Reference < embed::XEmbeddedObject 
 					// this must be an object based on properties, otherwise we can not copy it currently
 					uno::Reference< beans::XPropertySet > xOrigProps( xObj->getComponent(), uno::UNO_QUERY_THROW );
 
-					// use object class ID to create a new one and tranfer all the properties
+					// use object class ID to create a new one and transfer all the properties
         			uno::Reference < embed::XEmbedObjectCreator > xCreator(
 						::comphelper::getProcessServiceFactory()->createInstance(
                 			::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM("com.sun.star.embed.EmbeddedObjectCreator") ) ),
@@ -863,7 +863,7 @@ uno::Reference < embed::XEmbeddedObject 
 		}
 	}
 
-	OSL_ENSURE( xResult.is(), "Can not copy embedded object that has no persistance!\n" );
+	OSL_ENSURE( xResult.is(), "Can not copy embedded object that has no persistence!\n" );
 
 	if ( xResult.is() )
 	{
@@ -1033,7 +1033,7 @@ sal_Bool EmbeddedObjectContainer::Remove
 	uno::Reference < embed::XLinkageSupport > xLink( xPersist, uno::UNO_QUERY );
     sal_Bool bIsNotEmbedded = !xPersist.is() || xLink.is() && xLink->isLink();
 
-    // if the object has a persistance and the object is not a link than it must have persistence entry in the storage
+    // if the object has a persistence and the object is not a link than it must have persistence entry in the storage
     OSL_ENSURE( bIsNotEmbedded || xAccess->hasByName(aName), "Removing element not present in storage!" );
 #endif
 
@@ -1147,7 +1147,7 @@ sal_Bool EmbeddedObjectContainer::Remove
         try
         {
 #if OSL_DEBUG_LEVEL > 1
-			// if the object has a persistance and the object is not a link than it must have persistence entry in storage
+			// if the object has a persistence and the object is not a link than it must have persistence entry in storage
             OSL_ENSURE( bIsNotEmbedded || pImpl->mxStorage->hasByName( aName ), "The object has no persistence entry in the storage!" );
 #endif
             if ( xPersist.is() && pImpl->mxStorage->hasByName( aName ) )
@@ -1551,10 +1551,10 @@ sal_Bool EmbeddedObjectContainer::StoreC
                         }
                         else
                         {
-                            //do nothing.embeded model is not modified, no need to persist.
+                            //do nothing. Embedded model is not modified, no need to persist.
                         }
                     }
-                    else //the embeded object is in active status, always store back it.
+                    else //the embedded object is in active status, always store back it.
                     {
                         xPersist->storeOwn(); 
                     } 
@@ -751,7 +751,7 @@ uno::Reference < embed::XEmbeddedObject 
         rName = CreateUniqueObjectName();
 
-	// objects without persistance are not really stored by the method
+	// objects without persistence are not really stored by the method
    	if ( xObj.is() && StoreEmbeddedObject( xObj, rName, sal_True ) )
 	{

Modified: openoffice/trunk/main/comphelper/source/container/enumerablemap.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/comphelper/source/container/enumerablemap.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/comphelper/source/misc/mediadescriptor.cxx (original)
+++ openoffice/trunk/main/comphelper/source/misc/mediadescriptor.cxx Tue Apr 29 19:05:05 2014
@@ -715,7 +715,7 @@ sal_Bool MediaDescriptor::impl_openStrea
 	css::uno::Reference< css::ucb::XCommandEnvironment > xCommandEnv(static_cast< css::ucb::XCommandEnvironment* >(pCommandEnv), css::uno::UNO_QUERY);
 
     // try to create the content
-	// no content -> no stream => return immediatly with FALSE
+	// no content -> no stream => return immediately with FALSE
 	::ucbhelper::Content                      aContent;
     css::uno::Reference< css::ucb::XContent > xContent;
     try
@@ -733,7 +733,7 @@ sal_Bool MediaDescriptor::impl_openStrea
     // try to open the file in read/write mode
     // (if its allowed to do so).
     // But handle errors in a "hidden mode". Because
     // we try it readonly later - if read/write isnt an option.
     css::uno::Reference< css::io::XStream >      xStream     ;
     css::uno::Reference< css::io::XInputStream > xInputStream;
 
@@ -750,7 +750,7 @@ sal_Bool MediaDescriptor::impl_openStrea
     {
         try
         {
-            // TODO: use "special" still interaction to supress error messages
+            // TODO: use "special" still interaction to suppress error messages
             xStream = aContent.openWriteableStream();
             if (xStream.is())
                 xInputStream = xStream->getInputStream();
@@ -771,7 +771,7 @@ sal_Bool MediaDescriptor::impl_openStrea
             }
     }
 
-    // If opening of the stream in read/write mode wasnt allowed
+    // If opening of the stream in read/write mode wasn't allowed
     // or failed by an error - we must try it in readonly mode.
     if (!xInputStream.is())
     {
@@ -846,7 +846,7 @@ sal_Bool MediaDescriptor::impl_openStrea
        they are part of an URL.
 
        Do not use the URLTransformer service here. Because
-       it parses the URL in another way. It's main part isnt enough
+       it parses the URL in another way. It's main part isn't enough
        and it's complete part contains the jumpmark (fragment) parameter ...
     */
     static ::rtl::OUString SERVICENAME_URIREFERENCEFACTORY = ::rtl::OUString::createFromAscii("com.sun.star.uri.UriReferenceFactory");
@@ -867,7 +867,7 @@ sal_Bool MediaDescriptor::impl_openStrea
     catch(const css::uno::Exception&)
         {}
 
-    // If an error ocurred ... return the original URL.
+    // If an error occurred ... return the original URL.
     // It's a try .-)
     return sURL;
 }
@@ -733,7 +733,7 @@ sal_Bool MediaDescriptor::impl_openStrea
     // (if its allowed to do so).
     // But handle errors in a "hidden mode". Because
-    // we try it readonly later - if read/write isnt an option.
+    // we try it readonly later - if read/write isn't an option.
     css::uno::Reference< css::io::XStream >      xStream     ;
     css::uno::Reference< css::io::XInputStream > xInputStream;

Modified: openoffice/trunk/main/comphelper/source/misc/numberedcollection.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/comphelper/source/misc/numberedcollection.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/connectivity/inc/connectivity/sqliterator.hxx (original)
+++ openoffice/trunk/main/connectivity/inc/connectivity/sqliterator.hxx Tue Apr 29 19:05:05 2014
@@ -166,7 +166,7 @@ namespace connectivity
 		const OSQLParseNode* getSimpleGroupByTree() const;
 		const OSQLParseNode* getSimpleHavingTree() const;
 
         /** returns the errors which occured during parsing.
 
             The returned object contains a chain (via SQLException::NextException) of SQLExceptions.
         */
@@ -333,12 +333,12 @@ namespace connectivity
         /** appends an SQLException corresponding to the given error code to our error collection
 
             @param  _eError
-                the code of the error which occured
+                the code of the error which occurred
             @param  _pReplaceToken1
-                if not <NULL/>, the first occurance of '#' in the error message will be replaced
+                if not <NULL/>, the first occurrence of '#' in the error message will be replaced
                 with the given token
             @param  _pReplaceToken2
-                if not <NULL/>, and if _rReplaceToken1 is not <NULL/>, the second occurance of '#'
+                if not <NULL/>, and if _rReplaceToken1 is not <NULL/>, the second occurrence of '#'
                 in the error message will be replaced with _rReplaceToken2
         */
         void impl_appendError( IParseContext::ErrorCode _eError,
@@ -166,7 +166,7 @@ namespace connectivity
 		const OSQLParseNode* getSimpleHavingTree() const;
 
-        /** returns the errors which occured during parsing.
+        /** returns the errors which occurred during parsing.
 
             The returned object contains a chain (via SQLException::NextException) of SQLExceptions.

Modified: openoffice/trunk/main/connectivity/inc/connectivity/sqlnode.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/connectivity/inc/connectivity/sqlnode.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================